@@ -23,6 +23,7 @@
 #include <QWindow>
 
 #include <KLocalizedString>
+#include <kconfiggroup.h>
 
 #include "comicmodel.h"
 
@@ -51,6 +52,10 @@ void ComicApplet::dataUpdated(const ComicMetaData &data)
     const QString source = data.identifier;
     setBusy(false);
 
+    if (mEngine->isCheckingForUpdates() && config().readEntry(QLatin1String("checkNewComicStripsIntervall"), 30) == 0) {
+        mEngine->setIsCheckingForUpdates(false); // turn it back off if auto-updates are disabled
+    }
+
     // disconnect prefetched comic strips
     if (source != mOldSource) {
         return;
@@ -60,7 +65,7 @@ void ComicApplet::dataUpdated(const ComicMetaData &data)
 
     // looking at the last index, thus not mark it as new
     KConfigGroup cg = config();
-    if (!data.error && !mCurrent.hasNext() && cg.readEntry(QLatin1String("checkNewComicStripsIntervall"), 0)) {
+    if (!data.error && !mCurrent.hasNext() && cg.readEntry(QLatin1String("checkNewComicStripsIntervall"), 30)) {
         setTabHighlighted(mCurrent.id(), false);
     }
 
@@ -91,23 +96,30 @@ void ComicApplet::positionFullView(QWindow *window)
 
 void ComicApplet::updateUsedComics()
 {
-    loadProviders();
-
     KConfigGroup cg = config();
-    for (int i = 0; i < mModel->rowCount(); ++i) {
-        QModelIndex index = mModel->index(i, 0);
-        if (index.data(ComicModel::Roles::ComicEnabledRole).toBool() && cg.readEntry(QLatin1String("checkNewComicStripsIntervall"), 0)
-            && !cg.readEntry(QLatin1String("lastStripVisited_") + index.data(ComicModel::Roles::ComicPluginRole).toString(), true)) {
-            mModel->setHighlight(index, true);
+    const bool enabledProvidersChanged = cg.readEntry("tabIdentifier", QStringList()) != mModel->enabledProviders();
+    const int checkInterval = cg.readEntry(QLatin1String("checkNewComicStripsIntervall"), 30);
+
+    if (enabledProvidersChanged) {
+        loadProviders();
+
+        KConfigGroup cg = config();
+        for (int i = 0; i < mModel->rowCount(); ++i) {
+            QModelIndex index = mModel->index(i, 0);
+            if (index.data(ComicModel::Roles::ComicEnabledRole).toBool() && checkInterval
+                && !cg.readEntry(QLatin1String("lastStripVisited_") + index.data(ComicModel::Roles::ComicPluginRole).toString(), true)) {
+                mModel->setHighlight(index, true);
+            }
         }
     }
 
-    delete mCheckNewStrips;
-    mCheckNewStrips = nullptr;
-    if (cg.readEntry(QLatin1String("checkNewComicStripsIntervall"), 0)) {
-        mCheckNewStrips =
-            new CheckNewStrips(cg.readEntry("tabIdentifier", QStringList()), mEngine, cg.readEntry(QLatin1String("checkNewComicStripsIntervall"), 0), this);
-        connect(mCheckNewStrips, &CheckNewStrips::lastStrip, this, &ComicApplet::slotFoundLastStrip);
+    if (enabledProvidersChanged || !mCheckNewStrips || checkInterval != mCheckNewStrips->minutes()) {
+        delete mCheckNewStrips;
+        mCheckNewStrips = nullptr;
+        if (checkInterval) {
+            mCheckNewStrips = new CheckNewStrips(cg.readEntry("tabIdentifier", QStringList()), mEngine, checkInterval, this);
+            connect(mCheckNewStrips, &CheckNewStrips::lastStrip, this, &ComicApplet::slotFoundLastStrip);
+        }
     }
 }
 
@@ -166,6 +178,10 @@ void ComicApplet::updateComic(const QString &identifierSuffix)
     if (!id.isEmpty()) {
         setBusy(true);
 
+        if (identifierSuffix.isEmpty() && config().readEntry(QLatin1String("checkNewComicStripsIntervall"), 30) == 0) {
+            mEngine->setIsCheckingForUpdates(true); // if auto-updates are off, we need to check every current request
+        }
+
         const QString identifier = id + QLatin1Char(':') + identifierSuffix;
 
         // disconnecting of the oldSource is needed, otherwise you could get data for comics you are not looking at if you use tabs
